import { FollowButton } from "@/components/follow-button"
import { Icons } from "@/components/icons"
import { AspectRatio } from "@/components/ui/aspect-ratio"
import { UserAvatar } from "@/components/user-avatar"
import { getCurrentUser } from "@/lib/session"
import Image from "next/image"
import Link from "next/link"
import { IUser } from "../types"
import { following } from "../utils/following"
import { EditProfileModal } from "./edit-profile-modal"
import { UserJoinDate } from "./user-join-date"

export const ProfileUserInfo = async ({ user }: { user: IUser }) => {
    const session = await getCurrentUser()

    const isFollowing = following({
        user,
        sessionUserId: session ? session.id : "",
    })

    return (
        <>
            <AspectRatio ratio={3 / 1} className="bg-muted w-full overflow-hidden">
                {user.banner &&
                    <Image
                        src={user.banner}
                        alt={"user banner image"}
                        fill
                        priority
                        className="object-center object-cover w-full h-full"
                    />
                }
            </AspectRatio>
            <div className="relative">
                <div className="flex items-end justify-between p-6 md:px-12">
                    <div>
                        <div className="absolute bottom-6 md:bottom-3">
                            <UserAvatar
                                user={{ username: user.username, image: user.image || null }}
                                className="h-20 md:h-40 w-20 md:w-40"
                            />
                        </div>
                    </div>
                    <div>
                        {session?.id === user.id ? (
                            <EditProfileModal user={user} />
                        ) : (
                            <FollowButton
                                userId={user.id}
                                username={user.username ? user.username : ""}
                                isFollowing={isFollowing}
                            />
                        )}
                    </div>
                </div>
            </div>

            <div className="px-6 md:px-12 flex flex-col space-y-3 w-full">
                <div className="pb-3 whitespace-nowrap items-center">
                    <h1 className="text-2xl font-bold">{user.name}</h1>
                    <h1 className="text-md text-sky-500">@{user.username}</h1>
                </div>
                {user.bio && <h1 className="break-words">{user.bio}</h1>}

                <div className="flex flex-wrap whitespace-nowrap items-center text-muted-foreground">
                    {user.location &&
                        <div className="flex items-center mr-6 mb-3">
                            <Icons.location className="mr-1" />
                            <div>{user.location}</div>
                        </div>
                    }
                    {user.website &&
                        <div className="flex items-center mr-6 mb-3">
                            <Icons.website className="mr-1" />
                            <Link href={user.website} prefetch={false} target="_blank">
                                {user.website.replace("http://", "").replace("https://", "").replace("www.", "")}
                            </Link>
                        </div>
                    }
                    {user.createdAt && <UserJoinDate date={user.createdAt} />}
                </div>

                <div className="flex whitespace-nowrap items-center space-x-6">
                    <Link href={`/${user.username}/following`}>
                        <span className="font-bold">{user._count?.following}</span>
                        <span className="text-muted-foreground"> Following</span>
                    </Link>

                    <Link href={`/${user.username}/followers`}>
                        <span className="font-bold">{user._count?.followers}</span>
                        <span className="text-muted-foreground"> Followers</span>
                    </Link>
                </div>
            </div>
        </ >
    )
}